<?php

namespace Drupal\uptime_widget\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides an 'Uptime' block.
 *
 * @Block(
 *   id = "uptime_widget_fancy_block",
 *   admin_label = @Translation("Uptime")
 * )
 */
class UptimeWidgetFancyBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['selected_widget'] = [
      '#type' => 'select',
      '#title' => t('Widget'),
      '#options' => [
        'all' => $this->t('All widgets'),
        'uptime' => $this->t('Uptime widget'),
        'copyright' => $this->t('Copyright widget'),
      ],
      '#default_value' => isset($config['selected_widget']) ? $config['selected_widget'] : 'all',
      '#description' => $this->t('Select the widget which will be shown in this block.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);

    $values = $form_state->getValues();
    $this->configuration['selected_widget'] = $values['selected_widget'];
  }

  /**
   * The fancy version of the uptime block.
   */
  public function build() {
    $is_uptime_enabled = \Drupal::config('uptime_widget.settings')->get('enabled');
    $is_notice_enabled = \Drupal::config('uptime_widget.settings')->get('notice_enabled');
    $build = [];
    if ($is_uptime_enabled || $is_notice_enabled) {
      $build = [
        '#theme' => 'uptime_widget_fancy_block',
        '#selected_widget' => $this->configuration['selected_widget'],
      ];
    }
    return $build;
  }

}
